"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from skylight_sdk.types import BaseModel
from typing_extensions import TypedDict


class InstanceStatusResponseTypedDict(TypedDict):
    state: str
    r"""Current state of the instance"""
    knowledge: str
    r"""Current knowledge of the instance"""


class InstanceStatusResponse(BaseModel):
    state: str
    r"""Current state of the instance"""

    knowledge: str
    r"""Current knowledge of the instance"""
